GrowingBuffer

Struct GrowingBuffer 

pub struct GrowingBuffer<'label> { /* private fields */ }
Dynamically resizing buffer.

Implementations

Source

impl<'label> GrowingBuffer<'label>

pub const fn new( label: Option<Cow<'label, str>>, usages: BufferUsages, mapped_at_creation: bool, ) -> Self

pub const fn size(&self) -> BufferAddress

pub fn get(&mut self, device: &Device, size: BufferAddress) -> (&Buffer, bool)

Allocate and provide buffer given size. Return reference to buffer and bool if the buffer is mapped The size of buffer can be larger than requested size. Reusing buffer if possible.